@@ -71,7 +71,7 @@ CommandLineParser::CommandLineParser(Reactor& reactor_)
 	#endif
 	registerOption("-testconfig", testConfigOption, PHASE_BEFORE_SETTINGS, 1);
 
-	registerOption("-machine",    machineOption, PHASE_BEFORE_MACHINE);
+	registerOption("-machine",    machineOption, PHASE_LOAD_MACHINE);
 
 	registerFileType("tcl", scriptOption);
 
@@ -80,10 +80,6 @@ CommandLineParser::CommandLineParser(Reactor& reactor_)
 	sort(begin(fileTypes), end(fileTypes), CmpFileTypes());
 }
 
-CommandLineParser::~CommandLineParser()
-{
-}
-
 void CommandLineParser::registerOption(
 	const char* str, CLIOption& cliOption, ParsePhase phase, unsigned length)
 {
@@ -138,7 +134,7 @@ bool CommandLineParser::parseFileName(const string& arg, array_ref<string>& cmdL
 
 bool CommandLineParser::parseFileNameInner(const string& name, const string& originalPath, array_ref<string>& cmdLine)
 {
-	string_ref extension = FileOperations::getExtension(name);
+	string_ref extension = FileOperations::getExtension(name).substr(1);
 	if (extension.empty()) {
 		return false; // no extension
 	}
@@ -213,7 +209,7 @@ void CommandLineParser::parse(int argc, char** argv)
 				settingsConfig.setSaveFilename(context, filename);
 			}
 			break;
-		case PHASE_LOAD_MACHINE: {
+		case PHASE_DEFAULT_MACHINE: {
 			if (!haveConfig) {
 				// load default config file in case the user didn't specify one
 				const auto& machine =
