@@ -8,9 +8,9 @@
 namespace openmsx {
 
 Connector::Connector(PluggingController& pluggingController_,
-                     string_ref name_, std::unique_ptr<Pluggable> dummy_)
+                     std::string name_, std::unique_ptr<Pluggable> dummy_)
 	: pluggingController(pluggingController_)
-	, name(name_.str())
+	, name(std::move(name_))
 	, dummy(std::move(dummy_))
 {
 	plugged = dummy.get();
