@@ -5,6 +5,7 @@
 #include "FraelSwitchableROM.hh"
 #include "MSXRam.hh"
 #include "MSXPPI.hh"
+#include "SVIPPI.hh"
 #include "VDP.hh"
 #include "MSXE6Timer.hh"
 #include "MSXFacMidiInterface.hh"
@@ -15,6 +16,7 @@
 #include "MSXS1985.hh"
 #include "MSXS1990.hh"
 #include "MSXPSG.hh"
+#include "SVIPSG.hh"
 #include "MSXMusic.hh"
 #include "MSXFmPac.hh"
 #include "MSXAudio.hh"
@@ -25,11 +27,13 @@
 #include "MSXKanji.hh"
 #include "MSXBunsetsu.hh"
 #include "MSXMemoryMapper.hh"
+#include "MegaFlashRomSCCPlusSD.hh"
 #include "PanasonicRam.hh"
 #include "MSXRTC.hh"
 #include "PasswordCart.hh"
 #include "RomFactory.hh"
 #include "MSXPrinterPort.hh"
+#include "SVIPrinterPort.hh"
 #include "MSXSCCPlusCart.hh"
 #include "PhilipsFDC.hh"
 #include "MicrosolFDC.hh"
@@ -39,6 +43,7 @@
 #include "SanyoFDC.hh"
 #include "SpectravideoFDC.hh"
 #include "TurboRFDC.hh"
+#include "SVIFDC.hh"
 #include "SunriseIDE.hh"
 #include "BeerIDE.hh"
 #include "GoudaSCSI.hh"
@@ -115,6 +120,8 @@ unique_ptr<MSXDevice> DeviceFactory::create(const DeviceConfig& conf)
 	const std::string& type = conf.getXML()->getName();
 	if (type == "PPI") {
 		result = make_unique<MSXPPI>(conf);
+	} else if (type == "SVIPPI") {
+		result = make_unique<SVIPPI>(conf);
 	} else if (type == "RAM") {
 		result = make_unique<MSXRam>(conf);
 	} else if (type == "VDP") {
@@ -135,6 +142,8 @@ unique_ptr<MSXDevice> DeviceFactory::create(const DeviceConfig& conf)
 		result = make_unique<MSXS1990>(conf);
 	} else if (type == "PSG") {
 		result = make_unique<MSXPSG>(conf);
+	} else if (type == "SVIPSG") {
+		result = make_unique<SVIPSG>(conf);
 	} else if (type == "MSX-MUSIC") {
 		result = make_unique<MSXMusic>(conf);
 	} else if (type == "MSX-MUSIC-WX") {
@@ -169,6 +178,8 @@ unique_ptr<MSXDevice> DeviceFactory::create(const DeviceConfig& conf)
 		result = RomFactory::create(conf);
 	} else if (type == "PrinterPort") {
 		result = make_unique<MSXPrinterPort>(conf);
+	} else if (type == "SVIPrinterPort") {
+		result = make_unique<SVIPrinterPort>(conf);
 	} else if (type == "SCCplus") { // Note: it's actually called SCC-I
 		result = make_unique<MSXSCCPlusCart>(conf);
 	} else if ((type == "WD2793") || (type == "WD1770")) {
@@ -186,6 +197,8 @@ unique_ptr<MSXDevice> DeviceFactory::create(const DeviceConfig& conf)
 		result = make_unique<NationalFDC>(conf);
 	} else if (type == "TC8566AF") {
 		result = make_unique<TurboRFDC>(conf);
+	} else if (type == "SVIFDC") {
+		result = make_unique<SVIFDC>(conf);
 	} else if (type == "BeerIDE") {
 		result = make_unique<BeerIDE>(conf);
 	} else if (type == "SunriseIDE") {
@@ -242,6 +255,8 @@ unique_ptr<MSXDevice> DeviceFactory::create(const DeviceConfig& conf)
 		result = make_unique<FraelSwitchableROM>(conf);
 	} else if (type == "ChakkariCopy") {
 		result = make_unique<ChakkariCopy>(conf);
+	} else if (type == "MegaFlashRomSCCPlusSD") {
+		result = make_unique<MegaFlashRomSCCPlusSD>(conf);
 	} else if (type == "T9769") {
 		// Ignore for now. We might want to create a real device for it later.
 	} else {
