@@ -9,10 +9,6 @@ MSXException::MSXException(string_ref message_)
 {
 }
 
-MSXException::~MSXException()
-{
-}
-
 
 // class FatalError
 
@@ -21,8 +17,4 @@ FatalError::FatalError(string_ref message_)
 {
 }
 
-FatalError::~FatalError()
-{
-}
-
 } // namespace openmsx
