@@ -13,6 +13,7 @@
 #include "MidiInReader.hh"
 #include "MidiOutLogger.hh"
 #include "Mouse.hh"
+#include "Paddle.hh"
 #include "Trackball.hh"
 #include "Touchpad.hh"
 #include "PrinterPortLogger.hh"
@@ -36,8 +37,6 @@
 
 namespace openmsx {
 
-using std::unique_ptr;
-
 void PluggableFactory::createAll(PluggingController& controller,
                                  MSXMotherBoard& motherBoard)
 {
@@ -48,6 +47,7 @@ void PluggableFactory::createAll(PluggingController& controller,
 	auto& stateChangeDistributor = motherBoard.getStateChangeDistributor();
 	auto& eventDistributor       = reactor.getEventDistributor();
 	auto& globalSettings         = reactor.getGlobalSettings();
+	auto& display                = reactor.getDisplay();
 	// Input devices:
 	// TODO: Support hot-plugging of input devices:
 	// - additional key joysticks can be created by the user
@@ -56,11 +56,13 @@ void PluggableFactory::createAll(PluggingController& controller,
 		msxEventDistributor, stateChangeDistributor));
 	controller.registerPluggable(make_unique<Mouse>(
 		msxEventDistributor, stateChangeDistributor));
+	controller.registerPluggable(make_unique<Paddle>(
+		msxEventDistributor, stateChangeDistributor));
 	controller.registerPluggable(make_unique<Trackball>(
 		msxEventDistributor, stateChangeDistributor));
 	controller.registerPluggable(make_unique<Touchpad>(
 		msxEventDistributor, stateChangeDistributor,
-		commandController));
+		display, commandController));
 	controller.registerPluggable(make_unique<JoyTap>(
 		controller, "joytap"));
 	controller.registerPluggable(make_unique<NinjaTap>(
@@ -97,8 +99,13 @@ void PluggableFactory::createAll(PluggingController& controller,
 		commandController));
 
 	// MIDI:
+#if !defined(_WIN32)
+	// Devices and pipes are not usable as files on Windows, and MidiInReader
+	// reads all data as soon as it becomes available, so this pluggable is
+	// not useful on Windows.
 	controller.registerPluggable(make_unique<MidiInReader>(
 		eventDistributor, scheduler, commandController));
+#endif
 #if defined(_WIN32)
 	MidiInWindows::registerAll(eventDistributor, scheduler, controller);
 	MidiOutWindows::registerAll(controller);
