@@ -26,7 +26,6 @@ class Paper
 {
 public:
 	Paper(unsigned x, unsigned y, double dotSizeX, double dotSizeY);
-	~Paper();
 
 	std::string save() const;
 	void setDotSize(double sizeX, double sizeY);
@@ -47,15 +46,6 @@ private:
 };
 
 
-PrinterCore::PrinterCore()
-	: toPrint(0), prevStrobe(true)
-{
-}
-
-PrinterCore::~PrinterCore()
-{
-}
-
 bool PrinterCore::getStatus(EmuTime::param /*time*/)
 {
 	return false; // false = low = ready
@@ -1669,10 +1659,6 @@ Paper::Paper(unsigned x, unsigned y, double dotSizeX, double dotSizeY)
 	setDotSize(dotSizeX, dotSizeY);
 }
 
-Paper::~Paper()
-{
-}
-
 string Paper::save() const
 {
 	string filename = FileOperations::getNextNumberedFileName(
