@@ -123,10 +123,10 @@ void CassettePlayer::autoRun()
 	string instr1, instr2;
 	switch (type) {
 		case CassetteImage::ASCII:
-			instr1 = "RUN\\\"CAS:\\\"";
+			instr1 = R"(RUN\"CAS:\")";
 			break;
 		case CassetteImage::BINARY:
-			instr1 = "BLOAD\\\"CAS:\\\",R";
+			instr1 = R"(BLOAD\"CAS:\",R)";
 			break;
 		case CassetteImage::BASIC:
 			// Note that CLOAD:RUN won't work: BASIC ignores stuff
@@ -148,7 +148,7 @@ void CassettePlayer::autoRun()
 
 		// Without the 0.1s delay here, the type command gets messed up
 		// on MSX1 machines for some reason (starting to type too early?)
-		"    after time 0.1 \"type_via_keyboard [lindex $args 0]\\\\r\"\n"
+		"    after time 0.1 \"type [lindex $args 0]\\\\r\"\n"
 
 		"    set next [lrange $args 1 end]\n"
 		"    if {[llength $next] == 0} return\n"
