@@ -2,6 +2,7 @@
 #include "OSDTopWidget.hh"
 #include "OSDGUI.hh"
 #include "BaseImage.hh"
+#include "Display.hh"
 #include "OutputSurface.hh"
 #include "TclObject.hh"
 #include "CommandException.hh"
@@ -16,9 +17,8 @@ using namespace gl;
 
 namespace openmsx {
 
-OSDImageBasedWidget::OSDImageBasedWidget(OSDGUI& gui_, const TclObject& name_)
-	: OSDWidget(name_)
-	, gui(gui_)
+OSDImageBasedWidget::OSDImageBasedWidget(Display& display_, const TclObject& name_)
+	: OSDWidget(display_, name_)
 	, startFadeTime(0)
 	, fadePeriod(0.0)
 	, fadeTarget(1.0)
@@ -30,9 +30,7 @@ OSDImageBasedWidget::OSDImageBasedWidget(OSDGUI& gui_, const TclObject& name_)
 	}
 }
 
-OSDImageBasedWidget::~OSDImageBasedWidget()
-{
-}
+OSDImageBasedWidget::~OSDImageBasedWidget() = default;
 
 vector<string_ref> OSDImageBasedWidget::getProperties() const
 {
@@ -45,15 +43,15 @@ vector<string_ref> OSDImageBasedWidget::getProperties() const
 	return result;
 }
 
-static void get4(Interpreter& interp, const TclObject& value, unsigned* result)
+static void get4(Interpreter& interp, const TclObject& value, uint32_t* result)
 {
-	unsigned len = value.getListLength(interp);
+	auto len = value.getListLength(interp);
 	if (len == 4) {
 		for (auto i : xrange(4)) {
 			result[i] = value.getListIndex(interp, i).getInt(interp);
 		}
 	} else if (len == 1) {
-		unsigned val = value.getInt(interp);
+		uint32_t val = value.getInt(interp);
 		for (auto i : xrange(4)) {
 			result[i] = val;
 		}
@@ -65,22 +63,22 @@ void OSDImageBasedWidget::setProperty(
 	Interpreter& interp, string_ref propName, const TclObject& value)
 {
 	if (propName == "-rgba") {
-		unsigned newRGBA[4];
+		uint32_t newRGBA[4];
 		get4(interp, value, newRGBA);
 		setRGBA(newRGBA);
 	} else if (propName == "-rgb") {
-		unsigned newRGB[4];
+		uint32_t newRGB[4];
 		get4(interp, value, newRGB);
-		unsigned newRGBA[4];
+		uint32_t newRGBA[4];
 		for (auto i : xrange(4)) {
 			newRGBA[i] = (rgba[i]          & 0x000000ff) |
 			             ((newRGB[i] << 8) & 0xffffff00);
 		}
 		setRGBA(newRGBA);
 	} else if (propName == "-alpha") {
-		unsigned newAlpha[4];
+		uint32_t newAlpha[4];
 		get4(interp, value, newAlpha);
-		unsigned newRGBA[4];
+		uint32_t newRGBA[4];
 		for (auto i : xrange(4)) {
 			newRGBA[i] = (rgba[i]     & 0xffffff00) |
 			             (newAlpha[i] & 0x000000ff);
@@ -100,7 +98,7 @@ void OSDImageBasedWidget::setProperty(
 	}
 }
 
-void OSDImageBasedWidget::setRGBA(const unsigned newRGBA[4])
+void OSDImageBasedWidget::setRGBA(const uint32_t newRGBA[4])
 {
 	if ((rgba[0] == newRGBA[0]) &&
 	    (rgba[1] == newRGBA[1]) &&
@@ -115,7 +113,7 @@ void OSDImageBasedWidget::setRGBA(const unsigned newRGBA[4])
 	}
 }
 
-static void set4(const unsigned rgba[4], unsigned mask, unsigned shift, TclObject& result)
+static void set4(const uint32_t rgba[4], uint32_t mask, unsigned shift, TclObject& result)
 {
 	if ((rgba[0] == rgba[1]) && (rgba[0] == rgba[2]) && (rgba[0] == rgba[3])) {
 		result.setInt((rgba[0] & mask) >> shift);
@@ -145,7 +143,7 @@ void OSDImageBasedWidget::getProperty(string_ref propName, TclObject& result) co
 	}
 }
 
-static bool constantAlpha(const unsigned rgba[4])
+static bool constantAlpha(const uint32_t rgba[4])
 {
 	return ((rgba[0] & 0xff) == (rgba[1] & 0xff)) &&
 	       ((rgba[0] & 0xff) == (rgba[2] & 0xff)) &&
@@ -231,7 +229,7 @@ void OSDImageBasedWidget::setError(string message)
 	// the OSD widgets get created, but only the next frame, when this new
 	// widget is actually drawn the next error occurs.
 	if (!needSuppressErrors()) {
-		gui.getTopWidget().queueError(std::move(message));
+		getDisplay().getOSDGUI().getTopWidget().queueError(std::move(message));
 	}
 }
 
@@ -249,7 +247,7 @@ void OSDImageBasedWidget::createImage(OutputRectangle& output)
 {
 	if (!image && !hasError()) {
 		try {
-			if (gui.isOpenGL()) {
+			if (getDisplay().getOSDGUI().isOpenGL()) {
 				image = createGL(output);
 			} else {
 				image = createSDL(output);
@@ -265,16 +263,16 @@ void OSDImageBasedWidget::paint(OutputSurface& output, bool openGL)
 	// Note: Even when alpha == 0 we still create the image:
 	//    It may be needed to get the dimensions to be able to position
 	//    child widgets.
-	assert(openGL == gui.isOpenGL()); (void)openGL;
+	assert(openGL == getDisplay().getOSDGUI().isOpenGL()); (void)openGL;
 	createImage(output);
 
-	byte fadedAlpha = getFadedAlpha();
+	auto fadedAlpha = getFadedAlpha();
 	if ((fadedAlpha != 0) && image) {
 		ivec2 drawPos = round(getTransformedPos(output));
 		image->draw(output, drawPos, fadedAlpha);
 	}
 	if (isFading()) {
-		gui.refresh();
+		getDisplay().getOSDGUI().refresh();
 	}
 }
 
