@@ -10,12 +10,12 @@ namespace openmsx {
 unsigned ProbeBreakPoint::lastId = 0;
 
 ProbeBreakPoint::ProbeBreakPoint(
-		TclObject command,
-		TclObject condition,
+		TclObject command_,
+		TclObject condition_,
 		Debugger& debugger_,
 		ProbeBase& probe_,
 		unsigned newId /*= -1*/)
-	: BreakPointBase(command, condition)
+	: BreakPointBase(command_, condition_)
 	, debugger(debugger_)
 	, probe(probe_)
 	, id((newId == unsigned(-1)) ? ++lastId : newId)
