@@ -68,7 +68,6 @@ private:
 CliConnection::CliConnection(CommandController& commandController_,
                              EventDistributor& eventDistributor_)
 	: parser([this](const std::string& cmd) { execute(cmd); })
-	, thread(this)
 	, commandController(commandController_)
 	, eventDistributor(eventDistributor_)
 {
@@ -118,13 +117,19 @@ void CliConnection::startOutput()
 
 void CliConnection::start()
 {
-	thread.start();
+	thread = std::thread([this]() { run(); });
 }
 
 void CliConnection::end()
 {
 	output("</openmsx-output>\n");
 	close();
+
+	poller.abort();
+	// Thread might not be running if start() was never called.
+	if (thread.joinable()) {
+		thread.join();
+	}
 }
 
 void CliConnection::execute(const string& command)
@@ -163,7 +168,6 @@ static const int BUF_SIZE = 4096;
 StdioConnection::StdioConnection(CommandController& commandController_,
                                  EventDistributor& eventDistributor_)
 	: CliConnection(commandController_, eventDistributor_)
-	, ok(true)
 {
 	startOutput();
 }
@@ -176,13 +180,17 @@ StdioConnection::~StdioConnection()
 void StdioConnection::run()
 {
 	// runs in helper thread
-	while (ok) {
+	while (true) {
+#ifdef _WIN32
+		if (poller.aborted()) break;
+#else
+		if (poller.poll(STDIN_FILENO)) break;
+#endif
 		char buf[BUF_SIZE];
 		int n = read(STDIN_FILENO, buf, sizeof(buf));
 		if (n > 0) {
 			parser.parse(buf, n);
 		} else if (n < 0) {
-			close();
 			break;
 		}
 	}
@@ -190,15 +198,12 @@ void StdioConnection::run()
 
 void StdioConnection::output(string_ref message)
 {
-	if (ok) {
-		std::cout << message << std::flush;
-	}
+	std::cout << message << std::flush;
 }
 
 void StdioConnection::close()
 {
 	// don't close stdin/out/err
-	ok = false;
 }
 
 
@@ -237,6 +242,7 @@ PipeConnection::~PipeConnection()
 {
 	end();
 
+	assert(pipeHandle == OPENMSX_INVALID_HANDLE_VALUE);
 	CloseHandle(shutdownEvent);
 }
 
@@ -305,8 +311,6 @@ void PipeConnection::output(string_ref message)
 void PipeConnection::close()
 {
 	SetEvent(shutdownEvent);
-	thread.join();
-	assert(pipeHandle == OPENMSX_INVALID_HANDLE_VALUE);
 }
 #endif // _WIN32
 
@@ -332,14 +336,14 @@ void SocketConnection::run()
 #ifdef _WIN32
 	bool ok;
 	{
-		std::lock_guard<std::mutex> lock(mutex);
+		std::lock_guard<std::mutex> lock(sdMutex);
 		// Authenticate and authorize the caller
 		SocketStreamWrapper stream(sd);
 		SspiNegotiateServer server(stream);
 		ok = server.Authenticate() && server.Authorize();
 	}
 	if (!ok) {
-		close();
+		closeSocket();
 		return;
 	}
 #endif
@@ -352,15 +356,20 @@ void SocketConnection::run()
 	// and 'sd' only gets written to in this thread.
 	while (true) {
 		if (sd == OPENMSX_INVALID_SOCKET) return;
+#ifndef _WIN32
+		if (poller.poll(sd)) {
+			break;
+		}
+#endif
 		char buf[BUF_SIZE];
 		int n = sock_recv(sd, buf, BUF_SIZE);
 		if (n > 0) {
 			parser.parse(buf, n);
 		} else if (n < 0) {
-			close();
 			break;
 		}
 	}
+	closeSocket();
 }
 
 void SocketConnection::output(string_ref message)
@@ -376,7 +385,7 @@ void SocketConnection::output(string_ref message)
 	while (bytesLeft) {
 		int bytesSend;
 		{
-			std::lock_guard<std::mutex> lock(mutex);
+			std::lock_guard<std::mutex> lock(sdMutex);
 			if (sd == OPENMSX_INVALID_SOCKET) return;
 			bytesSend = sock_send(sd, &data[pos], bytesLeft);
 		}
@@ -384,15 +393,19 @@ void SocketConnection::output(string_ref message)
 			bytesLeft -= bytesSend;
 			pos += bytesSend;
 		} else {
-			close();
+			// Note: On Windows we rely on closing the socket to
+			//       wake up the worker thread, on other platforms
+			//       we rely on Poller.
+			closeSocket();
+			poller.abort();
 			break;
 		}
 	}
 }
 
-void SocketConnection::close()
+void SocketConnection::closeSocket()
 {
-	std::lock_guard<std::mutex> lock(mutex);
+	std::lock_guard<std::mutex> lock(sdMutex);
 	if (sd != OPENMSX_INVALID_SOCKET) {
 		SOCKET _sd = sd;
 		sd = OPENMSX_INVALID_SOCKET;
@@ -400,4 +413,9 @@ void SocketConnection::close()
 	}
 }
 
+void SocketConnection::close()
+{
+	closeSocket();
+}
+
 } // namespace openmsx
