@@ -1,5 +1,6 @@
 #include "MSXFDC.hh"
 #include "RealDrive.hh"
+#include "Rom.hh"
 #include "XMLElement.hh"
 #include "StringOp.hh"
 #include "MSXException.hh"
@@ -10,7 +11,9 @@ namespace openmsx {
 
 MSXFDC::MSXFDC(const DeviceConfig& config, const std::string& romId)
 	: MSXDevice(config)
-	, rom(getName() + " ROM", "rom", config, romId)
+	, rom(config.findChild("rom")
+		? make_unique<Rom>(getName() + " ROM", "rom", config, romId)
+		: nullptr) // e.g. Spectravideo_SVI-328 doesn't have a diskrom
 {
 	bool singleSided = config.findChild("singlesided") != nullptr;
 	int numDrives = config.getChildDataAsInt("drives", 1);
@@ -33,9 +36,7 @@ MSXFDC::MSXFDC(const DeviceConfig& config, const std::string& romId)
 	}
 }
 
-MSXFDC::~MSXFDC()
-{
-}
+MSXFDC::~MSXFDC() = default;
 
 void MSXFDC::powerDown(EmuTime::param time)
 {
@@ -56,7 +57,7 @@ byte MSXFDC::peekMem(word address, EmuTime::param /*time*/) const
 
 const byte* MSXFDC::getReadCacheLine(word start) const
 {
-	return &rom[start & 0x3FFF];
+	return &(*rom)[start & 0x3FFF];
 }
 
 
