@@ -14,6 +14,7 @@
 #include "TurboRFDC.hh"
 #include "MSXCPU.hh"
 #include "CacheLine.hh"
+#include "Rom.hh"
 #include "MSXException.hh"
 #include "serialize.hh"
 
@@ -41,7 +42,7 @@ TurboRFDC::TurboRFDC(const DeviceConfig& config)
 	, controller(getScheduler(), reinterpret_cast<DiskDrive**>(drives),
 	             getCliComm(), getCurrentTime())
 	, romBlockDebug(*this, &bank, 0x4000, 0x4000, 14)
-	, blockMask((rom.getSize() / 0x4000) - 1)
+	, blockMask((rom->getSize() / 0x4000) - 1)
 	, type(parseType(config))
 {
 	reset(getCurrentTime());
@@ -187,7 +188,7 @@ void TurboRFDC::setBank(byte value)
 {
 	invalidateMemCache(0x4000, 0x4000);
 	bank = value & blockMask;
-	memory = &rom[0x4000 * bank];
+	memory = &(*rom)[0x4000 * bank];
 }
 
 byte* TurboRFDC::getWriteCacheLine(word address) const
