@@ -30,11 +30,14 @@ static const int E_FLAG     = 0x04;
 static const int H_FLAG     = 0x08;
 static const int T_FLAG     = 0x10;
 static const int M_FLAG     = 0x10;
+static const int A0_FLAG    = 0x01;
 static const int N2R_IRQ    = 0x01;
 static const int R2N_IRQ    = 0x02;
 static const int IDX_IRQ    = 0x04;
 static const int IMM_IRQ    = 0x08;
 
+// HLD/HLT timing constants
+const EmuDuration WD2793::IDLE = EmuDuration::sec(3);
 
 /** This class has emulation for WD1770, WD1793, WD2793. Though at the moment
  * the only emulated difference between WD1770 and WD{12}793 is that WD1770
@@ -49,13 +52,17 @@ WD2793::WD2793(Scheduler& scheduler_, DiskDrive& drive_, CliComm& cliComm_,
 	, drqTime(EmuTime::infinity)
 	, irqTime(EmuTime::infinity)
 	, pulse5(EmuTime::infinity)
+	, hldTime(EmuTime::infinity) // HLD=false
 	, isWD1770(isWD1770_)
 {
 	// avoid (harmless) UMR in serialize()
 	dataCurrent = 0;
 	dataAvailable = 0;
+	dataOutReg = 0;
+	dataRegWritten = false;
 	lastWasA1 = false;
-	setDrqRate();
+	lastWasCRC = false;
+	setDrqRate(RawTrack::STANDARD_SIZE);
 
 	reset(time);
 }
@@ -89,9 +96,9 @@ bool WD2793::peekDTRQ(EmuTime::param time) const
 	return time >= drqTime.getTime();
 }
 
-void WD2793::setDrqRate()
+void WD2793::setDrqRate(unsigned trackLength)
 {
-	drqTime.setFreq(trackData.getLength() * DiskDrive::ROTATIONS_PER_SECOND);
+	drqTime.setFreq(trackLength * DiskDrive::ROTATIONS_PER_SECOND);
 }
 
 bool WD2793::getIRQ(EmuTime::param time)
@@ -113,6 +120,13 @@ bool WD2793::isReady() const
 
 void WD2793::setCommandReg(byte value, EmuTime::param time)
 {
+	if (((commandReg & 0xE0) == 0xA0) || // write sector
+	    ((commandReg & 0xF0) == 0xF0)) { // write track
+		// If a write sector/track command is cancelled, still flush
+		// the partially written data to disk.
+		drive.flushTrack();
+	}
+
 	removeSyncPoint();
 
 	commandReg = value;
@@ -159,7 +173,7 @@ byte WD2793::getStatusReg(EmuTime::param time)
 		if (drive.isTrack00()) {
 			statusReg |=  TRACK00;
 		}
-		if (drive.headLoaded(time)) {
+		if ((hldTime <= time) && (time < (hldTime + IDLE))) {
 			statusReg |=  HEAD_LOADED;
 		}
 		if (drive.isWriteProtected()) {
@@ -233,67 +247,8 @@ void WD2793::setDataReg(byte value, EmuTime::param time)
 
 	if (((commandReg & 0xE0) == 0xA0) || // write sector
 	    ((commandReg & 0xF0) == 0xF0)) { // write track
-		if (fsmState == FSM_CHECK_WRITE) {
-			// 1st byte of a write sector command,
-			// don't automatically re-activate DTRQ
-			drqTime.reset(EmuTime::infinity); // DRQ = false
-		} else {
-			// handle lost bytes
-			drqTime += 1; // time when next byte will be accepted
-			while (dataAvailable && unlikely(getDTRQ(time))) {
-				statusReg |= LOST_DATA;
-				drqTime += 1;
-				trackData.write(dataCurrent++, 0);
-				crc.update(0);
-				dataAvailable--;
-			}
-		}
-
-		byte write = value; // written value not always same as given value
-		if ((commandReg & 0xF0) == 0xF0) {
-			// write track, handle chars with special meaning
-			bool prevA1 = lastWasA1;
-			lastWasA1 = false;
-			if (value == 0xF5) {
-				// write A1 with missing clock transitions
-				write = 0xA1;
-				lastWasA1 = true;
-				// Initialize CRC: the calculated CRC value
-				// includes the 3 A1 bytes. So when starting
-				// from the initial value 0xffff, we should not
-				// re-initialize the CRC value on the 2nd and
-				// 3rd A1 byte. Though what we do instead is on
-				// each A1 byte initialize the value as if
-				// there were already 2 A1 bytes written.
-				crc.init<0xA1, 0xA1>();
-			} else if (value == 0xF6) {
-				// write C2 with missing clock transitions
-				write = 0xC2;
-			} else if (value == 0xF7) {
-				// write 2 CRC bytes, big endian
-				word crcVal = crc.getValue();
-				if (dataAvailable) {
-					drqTime += 1;
-					trackData.write(dataCurrent++, crcVal >> 8);
-					dataAvailable--;
-				}
-				write = crcVal & 0xFF;
-			} else if (value == 0xFE) {
-				// Record locations of 0xA1 (with missing clock
-				// transition) followed by 0xFE. The FE byte has
-				// no special meaning for the WD2793 itself,
-				// but it does for the DMK file format.
-				if (prevA1) {
-					trackData.addIdam(dataCurrent);
-				}
-			}
-		}
-		if (dataAvailable) {
-			trackData.write(dataCurrent++, write);
-			crc.update(write);
-			dataAvailable--;
-		}
-		assert(!dataAvailable || !getDTRQ(time));
+		dataRegWritten = true;
+		drqTime.reset(EmuTime::infinity); // DRQ = false
 	}
 }
 
@@ -305,13 +260,13 @@ byte WD2793::getDataReg(EmuTime::param time)
 	    getDTRQ(time)) {
 		assert(statusReg & BUSY);
 
-		dataReg = trackData.read(dataCurrent++);
+		dataReg = drive.readTrackByte(dataCurrent++);
 		crc.update(dataReg);
 		dataAvailable--;
 		drqTime += 1; // time when the next byte will be available
 		while (dataAvailable && unlikely(getDTRQ(time))) {
 			statusReg |= LOST_DATA;
-			dataReg = trackData.read(dataCurrent++);
+			dataReg = drive.readTrackByte(dataCurrent++);
 			crc.update(dataReg);
 			dataAvailable--;
 			drqTime += 1;
@@ -321,24 +276,40 @@ byte WD2793::getDataReg(EmuTime::param time)
 			if ((commandReg & 0xE0) == 0x80) {
 				// read sector
 				// update crc status flag
-				word diskCrc  = 256 * trackData.read(dataCurrent++);
-				     diskCrc +=       trackData.read(dataCurrent++);
+				word diskCrc  = 256 * drive.readTrackByte(dataCurrent++);
+				     diskCrc +=       drive.readTrackByte(dataCurrent++);
 				if (diskCrc == crc.getValue()) {
 					statusReg &= ~CRC_ERROR;
 				} else {
 					statusReg |=  CRC_ERROR;
 				}
+				if (sectorInfo.deleted) {
+					// TODO datasheet isn't clear about this:
+					// Set this flag at the end of the
+					// command or as soon as the marker is
+					// encountered on the disk?
+					statusReg |= RECORD_TYPE;
+				}
 				if (!(commandReg & M_FLAG)) {
-					endCmd();
+					endCmd(time);
 				} else {
 					// TODO multi sector read
 					sectorReg++;
-					endCmd();
+					endCmd(time);
 				}
 			} else {
 				// read track, read address
-				// TODO check CRC error on 'read address'
-				endCmd();
+				if ((commandReg & 0xF0) == 0xE0) { // read track
+					drive.invalidateWd2793ReadTrackQuirk();
+				}
+				if ((commandReg & 0xF0) == 0xC0) { // read address
+					if (sectorInfo.addrCrcErr) {
+						statusReg |=  CRC_ERROR;
+					} else {
+						statusReg &= ~CRC_ERROR;
+					}
+				}
+				endCmd(time);
 			}
 		}
 	}
@@ -351,7 +322,7 @@ byte WD2793::peekDataReg(EmuTime::param time) const
 	     ((commandReg & 0xF0) == 0xC0) ||   // read address
 	     ((commandReg & 0xF0) == 0xE0)) &&  // read track
 	    peekDTRQ(time)) {
-		return trackData.read(dataCurrent);
+		return drive.readTrackByte(dataCurrent);
 	} else {
 		return dataReg;
 	}
@@ -376,12 +347,6 @@ void WD2793::executeUntil(EmuTime::param time)
 				seekNext(time);
 			}
 			break;
-		case FSM_TYPE2_WAIT_LOAD:
-			if ((commandReg & 0xC0) == 0x80)  {
-				// Type II command
-				type2WaitLoad(time);
-			}
-			break;
 		case FSM_TYPE2_LOADED:
 			if ((commandReg & 0xC0) == 0x80)  {
 				// Type II command
@@ -391,7 +356,7 @@ void WD2793::executeUntil(EmuTime::param time)
 		case FSM_TYPE2_NOT_FOUND:
 			if ((commandReg & 0xC0) == 0x80)  {
 				// Type II command
-				type2NotFound();
+				type2NotFound(time);
 			}
 			break;
 		case FSM_TYPE2_ROTATED:
@@ -406,17 +371,22 @@ void WD2793::executeUntil(EmuTime::param time)
 				checkStartWrite(time);
 			}
 			break;
+		case FSM_PRE_WRITE_SECTOR:
+			if ((commandReg & 0xE0) == 0xA0) {
+				// write sector command
+				preWriteSector(time);
+			}
+			break;
 		case FSM_WRITE_SECTOR:
 			if ((commandReg & 0xE0) == 0xA0) {
 				// write sector command
-				doneWriteSector();
+				writeSectorData(time);
 			}
 			break;
-		case FSM_TYPE3_WAIT_LOAD:
-			if (((commandReg & 0xC0) == 0xC0) &&
-			    ((commandReg & 0xF0) != 0xD0)) {
-				// Type III command
-				type3WaitLoad(time);
+		case FSM_POST_WRITE_SECTOR:
+			if ((commandReg & 0xE0) == 0xA0) {
+				// write sector command
+				postWriteSector(time);
 			}
 			break;
 		case FSM_TYPE3_LOADED:
@@ -436,13 +406,14 @@ void WD2793::executeUntil(EmuTime::param time)
 		case FSM_WRITE_TRACK:
 			if ((commandReg & 0xF0) == 0xF0) {
 				// write track command
-				doneWriteTrack();
+				writeTrackData(time);
 			}
 			break;
 		case FSM_READ_TRACK:
 			if ((commandReg & 0xF0) == 0xE0) {
 				// read track command
-				endCmd(); // TODO check this (e.g. DRQ)
+				drive.invalidateWd2793ReadTrackQuirk();
+				endCmd(time); // TODO check this (e.g. DRQ)
 			}
 			break;
 		default:
@@ -455,7 +426,15 @@ void WD2793::startType1Cmd(EmuTime::param time)
 	statusReg &= ~(SEEK_ERROR | CRC_ERROR);
 	statusReg |= BUSY;
 
-	drive.setHeadLoaded((commandReg & H_FLAG) != 0, time);
+	if (commandReg & H_FLAG) {
+		// Activate HLD, WD2793 now waits for the HLT response. But on
+		// all MSX machines I checked HLT is just stubbed to +5V. So
+		// from a WD2793 point of view the head is loaded immediately.
+		hldTime = time;
+	} else {
+		// deactivate HLD
+		hldTime = EmuTime::infinity;
+	}
 
 	switch (commandReg & 0xF0) {
 		case 0x00: // restore
@@ -490,7 +469,7 @@ void WD2793::startType1Cmd(EmuTime::param time)
 void WD2793::seek(EmuTime::param time)
 {
 	if (trackReg == dataReg) {
-		endType1Cmd();
+		endType1Cmd(time);
 	} else {
 		directionIn = (dataReg > trackReg);
 		step(time);
@@ -514,7 +493,7 @@ void WD2793::step(EmuTime::param time)
 	}
 	if (!directionIn && drive.isTrack00()) {
 		trackReg = 0;
-		endType1Cmd();
+		endType1Cmd(time);
 	} else {
 		drive.step(directionIn, time);
 		schedule(FSM_SEEK,
@@ -528,17 +507,17 @@ void WD2793::seekNext(EmuTime::param time)
 		// Restore or seek
 		seek(time);
 	} else {
-		endType1Cmd();
+		endType1Cmd(time);
 	}
 }
 
-void WD2793::endType1Cmd()
+void WD2793::endType1Cmd(EmuTime::param time)
 {
 	if (commandReg & V_FLAG) {
 		// verify sequence
 		// TODO verify sequence
 	}
-	endCmd();
+	endCmd(time);
 }
 
 
@@ -547,34 +526,29 @@ void WD2793::startType2Cmd(EmuTime::param time)
 	statusReg &= ~(LOST_DATA   | RECORD_NOT_FOUND |
 	               RECORD_TYPE | WRITE_PROTECTED);
 	statusReg |= BUSY;
+	dataRegWritten = false;
 
 	if (!isReady()) {
-		endCmd();
+		endCmd(time);
 	} else {
 		// WD2795/WD2797 would now set SSO output
-		drive.setHeadLoaded(true, time);
+		hldTime = time; // see comment in startType1Cmd
 
 		if (commandReg & E_FLAG) {
-			schedule(FSM_TYPE2_WAIT_LOAD,
+			schedule(FSM_TYPE2_LOADED,
 			         time + EmuDuration::msec(30)); // when 1MHz clock
 		} else {
-			type2WaitLoad(time);
+			type2Loaded(time);
 		}
 	}
 }
 
-void WD2793::type2WaitLoad(EmuTime::param time)
-{
-	// TODO wait till head loaded, I arbitrarily took 1ms delay
-	schedule(FSM_TYPE2_LOADED, time + EmuDuration::msec(1));
-}
-
 void WD2793::type2Loaded(EmuTime::param time)
 {
 	if (((commandReg & 0xE0) == 0xA0) && (drive.isWriteProtected())) {
 		// write command and write protected
 		statusReg |= WRITE_PROTECTED;
-		endCmd();
+		endCmd(time);
 		return;
 	}
 
@@ -587,8 +561,8 @@ void WD2793::type2Search(EmuTime::param time)
 	assert(time < pulse5);
 	// Locate (next) sector on disk.
 	try {
-		EmuTime next = drive.getNextSector(time, trackData, sectorInfo);
-		setDrqRate();
+		setDrqRate(drive.getTrackLength());
+		EmuTime next = drive.getNextSector(time, sectorInfo);
 		if (next < pulse5) {
 			// Wait till sector is actually rotated under head
 			schedule(FSM_TYPE2_ROTATED, next);
@@ -603,7 +577,7 @@ void WD2793::type2Search(EmuTime::param time)
 		schedule(FSM_TYPE2_NOT_FOUND, pulse5);
 	} else {
 		// Drive not rotating. How does a real WD293 handle this?
-		type2NotFound();
+		type2NotFound(time);
 	}
 }
 
@@ -623,17 +597,15 @@ void WD2793::type2Rotated(EmuTime::param time)
 		type2Search(time);
 		return;
 	}
+	if (sectorInfo.dataIdx == -1) {
+		// Sector header without accompanying data block.
+		// TODO we should actually wait for the disk to rotate before
+		// we can check this.
+		type2Search(time);
+		return;
+	}
 
 	// Ok, found matching sector.
-	// Get sectorsize from disk: 128, 256, 512 or 1024 bytes
-	// Verified on real WD2793:
-	//   sizecode=255 results in a sector size of 1024 bytes,
-	// This suggests the WD2793 only looks at the lower 2 bits.
-	dataAvailable = 128 << (sectorInfo.sizeCode & 3);
-	dataCurrent = sectorInfo.dataIdx;
-
-	crc.init<0xA1, 0xA1, 0xA1, 0xFB>(); // TODO possibly A1 A1 A1 F8
-
 	switch (commandReg & 0xE0) {
 	case 0x80: // read sector  or  read sector multi
 		startReadSector(time);
@@ -645,18 +617,32 @@ void WD2793::type2Rotated(EmuTime::param time)
 	}
 }
 
-void WD2793::type2NotFound()
+void WD2793::type2NotFound(EmuTime::param time)
 {
 	statusReg |= RECORD_NOT_FOUND;
-	endCmd();
+	endCmd(time);
 }
 
 void WD2793::startReadSector(EmuTime::param time)
 {
-	unsigned gapLength = trackData.wrapIndex(
-		sectorInfo.dataIdx - sectorInfo.addrIdx);
+	if (sectorInfo.deleted) {
+		crc.init<0xA1, 0xA1, 0xA1, 0xF8>();
+	} else {
+		crc.init<0xA1, 0xA1, 0xA1, 0xFB>();
+	}
+	unsigned trackLength = drive.getTrackLength();
+	int tmp = sectorInfo.dataIdx >= sectorInfo.addrIdx;
+	unsigned gapLength = (tmp >= 0) ? tmp : (tmp + trackLength);
+	assert(gapLength < trackLength);
 	drqTime.reset(time);
 	drqTime += gapLength + 1 + 1; // (first) byte can be read in a moment
+	dataCurrent = sectorInfo.dataIdx;
+
+	// Get sectorsize from disk: 128, 256, 512 or 1024 bytes
+	// Verified on real WD2793:
+	//   sizecode=255 results in a sector size of 1024 bytes,
+	// This suggests the WD2793 only looks at the lower 2 bits.
+	dataAvailable = 128 << (sectorInfo.sizeCode & 3);
 }
 
 void WD2793::startWriteSector(EmuTime::param time)
@@ -670,18 +656,14 @@ void WD2793::startWriteSector(EmuTime::param time)
 	// - 8 bytes later the WD2793 will check that the CPU has send the
 	//   first byte (if not the command will be aborted without any writes
 	//   to the disk, not even gap or data mark bytes).
-	// - after a pauze of 12 bytes, the WD2793 will write 12 zero bytes,
+	// - after a pause of 12 bytes, the WD2793 will write 12 zero bytes,
 	//   followed by the 4 bytes data header (A1 A1 A1 FB).
 	// - Next the WD2793 write the actual data bytes. At this moment it
 	//   will also activate DRQ to receive the 2nd byte from the CPU.
 	//
 	// Note that between the 1st and 2nd activation of DRQ is a longer
-	// durtaion than between all later DRQ activations. The write-sector
+	// duration than between all later DRQ activations. The write-sector
 	// routine in Microsol_CDX-2 depends on this.
-	//
-	// TODO after the address header, the WD2793 skips 22 bytes and then
-	// starts writing. The current code instead reuses the location of
-	// the existing data block.
 
 	drqTime.reset(time);
 	drqTime += 7 + 2; // activate DRQ 2 bytes after end of address header
@@ -695,57 +677,135 @@ void WD2793::checkStartWrite(EmuTime::param time)
 {
 	// By now the CPU should already have written the first byte, otherwise
 	// the write sector command doesn't even start.
-	if (getDTRQ(time)) {
+	if (!dataRegWritten) {
 		statusReg |= LOST_DATA;
-		endCmd();
+		endCmd(time);
 		return;
 	}
 
-	// Moment in time when the first data byte will be written (and when
-	// DRQ will be re-activated for the 2nd byte).
-	drqTime.reset(time);
-	drqTime += 12 + 12 + 4;
+	// From this point onwards the FDC will write a full sector to the disk
+	// (including markers and CRC). If the CPU doesn't supply data bytes in
+	// a timely manner, the missing bytes are filled with zero.
+	//
+	// But it is possible to cancel the write sector command to only write
+	// a partial sector (e.g. without CRC bytes). See cbsfox' comment in
+	// this forum thread:
+	//    https://www.msx.org/forum/msx-talk/software/pdi-to-dmk-using-dsk-pro-104-with-openmsx
+	dataCurrent = sectorInfo.addrIdx
+	            + 6 // C H R N CRC1 CRC2
+		    + 22;
 
-	// Moment in time when the sector is fully written. At that time we
-	// will write the collected data to the disk image (whether the
-	// CPU wrote all required data or not).
-	assert((dataAvailable & 0x7F) == 0x7F); // already decreased by one.
-	schedule(FSM_WRITE_SECTOR, drqTime + (dataAvailable + 1));
+	// pause 12 bytes
+	drqTime.reset(time);
+	schedule(FSM_PRE_WRITE_SECTOR, drqTime + 12);
+	drqTime.reset(EmuTime::infinity); // DRQ = false
+	dataAvailable = 16; // 12+4 bytes pre-data
 }
 
-void WD2793::doneWriteSector()
+void WD2793::preWriteSector(EmuTime::param time)
 {
 	try {
-		// any lost data?
-		while (dataAvailable) {
-			statusReg |= LOST_DATA;
-			trackData.write(dataCurrent++, 0);
-			crc.update(0);
-			dataAvailable--;
-		}
-
-		// write 2 CRC bytes (big endian)
-		trackData.write(dataCurrent++, crc.getValue() >> 8);
-		trackData.write(dataCurrent++, crc.getValue() & 0xFF);
-		// write one byte of 0xFE
-		// TODO check this, datasheet is not very clear about this
-		trackData.write(dataCurrent++, 0xFE);
-
-		// write sector (actually full track) to disk.
-		drive.writeTrack(trackData);
-
-		if (!(commandReg & M_FLAG)) {
-			endCmd();
+		--dataAvailable;
+		if (dataAvailable > 0) {
+			if (dataAvailable >= 4) {
+				// write 12 zero-bytes
+				drive.writeTrackByte(dataCurrent++, 0x00);
+			} else {
+				// followed by 3x A1-bytes
+				drive.writeTrackByte(dataCurrent++, 0xA1);
+			}
+			drqTime.reset(time);
+			schedule(FSM_PRE_WRITE_SECTOR, drqTime + 1);
+			drqTime.reset(EmuTime::infinity); // DRQ = false
 		} else {
-			// TODO multi sector write
-			sectorReg++;
-			endCmd();
+			// and finally a single F8/FB byte
+			crc.init<0xA1, 0xA1, 0xA1>();
+			byte mark = (commandReg & A0_FLAG) ? 0xF8 : 0xFB;
+			drive.writeTrackByte(dataCurrent++, mark);
+			crc.update(mark);
+
+			// Pre-data is finished. Next start writing the actual data bytes
+			dataOutReg = dataReg;
+			dataRegWritten = false;
+			dataAvailable = 128 << (sectorInfo.sizeCode & 3); // see comment in startReadSector()
+
+			// Re-activate DRQ
+			drqTime.reset(time);
+
+			// Moment in time when first data byte gets written
+			schedule(FSM_WRITE_SECTOR, drqTime + 1);
 		}
 	} catch (MSXException&) {
-		// Backend couldn't write data
-		// TODO which status bit should be set?
-		statusReg |= RECORD_NOT_FOUND;
-		endCmd();
+		statusReg |= NOT_READY; // TODO which status bit should be set?
+		endCmd(time);
+	}
+}
+
+void WD2793::writeSectorData(EmuTime::param time)
+{
+	try {
+		// Write data byte
+		drive.writeTrackByte(dataCurrent++, dataOutReg);
+		crc.update(dataOutReg);
+		--dataAvailable;
+
+		if (dataAvailable > 0) {
+			if (dataRegWritten) {
+				dataOutReg = dataReg;
+				dataRegWritten = false;
+			} else {
+				dataOutReg = 0;
+				statusReg |= LOST_DATA;
+			}
+			// Re-activate DRQ
+			drqTime.reset(time);
+
+			// Moment in time when next data byte gets written
+			schedule(FSM_WRITE_SECTOR, drqTime + 1);
+		} else {
+			// Next write post-part
+			dataAvailable = 3;
+			drqTime.reset(time);
+			schedule(FSM_POST_WRITE_SECTOR, drqTime + 1);
+			drqTime.reset(EmuTime::infinity); // DRQ = false
+		}
+	} catch (MSXException&) {
+		statusReg |= NOT_READY; // TODO which status bit should be set?
+		endCmd(time);
+	}
+}
+
+void WD2793::postWriteSector(EmuTime::param time)
+{
+	try {
+		--dataAvailable;
+		if (dataAvailable > 0) {
+			// write 2 CRC bytes (big endian)
+			byte val = (dataAvailable == 2) ? (crc.getValue() >> 8)
+							: (crc.getValue() & 0xFF);
+			drive.writeTrackByte(dataCurrent++, val);
+			drqTime.reset(time);
+			schedule(FSM_POST_WRITE_SECTOR, drqTime + 1);
+			drqTime.reset(EmuTime::infinity); // DRQ = false
+		} else {
+			// write one byte of 0xFE
+			drive.writeTrackByte(dataCurrent++, 0xFE);
+
+			// flush sector (actually full track) to disk.
+			drive.flushTrack();
+
+			if (!(commandReg & M_FLAG)) {
+				endCmd(time);
+			} else {
+				// TODO multi sector write
+				sectorReg++;
+				endCmd(time);
+			}
+		}
+	} catch (MSXException&) {
+		// e.g. triggers when a different drive was selected during write
+		statusReg |= NOT_READY; // TODO which status bit should be set?
+		endCmd(time);
 	}
 }
 
@@ -756,33 +816,32 @@ void WD2793::startType3Cmd(EmuTime::param time)
 	statusReg |= BUSY;
 
 	if (!isReady()) {
-		endCmd();
+		endCmd(time);
 	} else {
-		drive.setHeadLoaded(true, time);
+		if ((commandReg & 0xF0) == 0xF0) { // write track
+			// immediately activate DRQ
+			drqTime.reset(time); // DRQ = true
+		}
+
+		hldTime = time; // see comment in startType1Cmd
 		// WD2795/WD2797 would now set SSO output
 
 		if (commandReg & E_FLAG) {
-			schedule(FSM_TYPE3_WAIT_LOAD,
+			schedule(FSM_TYPE3_LOADED,
 			         time + EmuDuration::msec(30)); // when 1MHz clock
 		} else {
-			type3WaitLoad(time);
+			type3Loaded(time);
 		}
 	}
 }
 
-void WD2793::type3WaitLoad(EmuTime::param time)
-{
-	// TODO wait till head loaded, I arbitrarily took 1ms delay
-	schedule(FSM_TYPE3_LOADED, time + EmuDuration::msec(1));
-}
-
 void WD2793::type3Loaded(EmuTime::param time)
 {
 	// TODO TG43 update
 	if (((commandReg & 0xF0) == 0xF0) && (drive.isWriteProtected())) {
 		// write track command and write protected
 		statusReg |= WRITE_PROTECTED;
-		endCmd();
+		endCmd(time);
 		return;
 	}
 
@@ -791,27 +850,32 @@ void WD2793::type3Loaded(EmuTime::param time)
 		// read address
 		try {
 			// wait till next sector header
-			RawTrack::Sector sector;
-			next = drive.getNextSector(time, trackData, sector);
-			setDrqRate();
+			setDrqRate(drive.getTrackLength());
+			next = drive.getNextSector(time, sectorInfo);
 			if (next == EmuTime::infinity) {
 				// TODO wait for 5 revolutions
 				statusReg |= RECORD_NOT_FOUND;
-				endCmd();
+				endCmd(time);
 				return;
 			}
-			dataCurrent = sector.addrIdx;
+			dataCurrent = sectorInfo.addrIdx;
 			dataAvailable = 6;
 		} catch (MSXException&) {
 			// read addr failed
 			statusReg |= RECORD_NOT_FOUND;
-			endCmd();
+			endCmd(time);
 			return;
 		}
 	} else {
 		// read/write track
 		// wait till next index pulse
 		next = drive.getTimeTillIndexPulse(time);
+		if (next == EmuTime::infinity) {
+			// drive became not ready since the command was started,
+			// how does a real WD2793 handle this?
+			endCmd(time);
+			return;
+		}
 	}
 	schedule(FSM_TYPE3_ROTATED, next);
 }
@@ -826,7 +890,7 @@ void WD2793::type3Rotated(EmuTime::param time)
 		readTrackCmd(time);
 		break;
 	case 0xF0: // write track
-		writeTrackCmd(time);
+		startWriteTrack(time);
 		break;
 	}
 }
@@ -840,10 +904,11 @@ void WD2793::readAddressCmd(EmuTime::param time)
 void WD2793::readTrackCmd(EmuTime::param time)
 {
 	try {
-		drive.readTrack(trackData);
-		setDrqRate();
+		unsigned trackLength = drive.getTrackLength();
+		drive.applyWd2793ReadTrackQuirk();
+		setDrqRate(trackLength);
 		dataCurrent = 0;
-		dataAvailable = trackData.getLength();
+		dataAvailable = trackLength;
 		drqTime.reset(time);
 
 		// Stop command at next index pulse
@@ -852,56 +917,112 @@ void WD2793::readTrackCmd(EmuTime::param time)
 		drqTime += 1; // (first) byte can be read in a moment
 	} catch (MSXException&) {
 		// read track failed, TODO status bits?
-		endCmd();
+		drive.invalidateWd2793ReadTrackQuirk();
+		endCmd(time);
 	}
 }
 
-void WD2793::writeTrackCmd(EmuTime::param time)
+void WD2793::startWriteTrack(EmuTime::param time)
 {
-	// TODO By now the CPU should already have written the first byte,
-	// otherwise the write track command doesn't even start. This is not
-	// yet implemented.
+	// By now the CPU should already have written the first byte, otherwise
+	// the write track command doesn't even start.
+	if (!dataRegWritten) {
+		statusReg |= LOST_DATA;
+		endCmd(time);
+		return;
+	}
 	try {
-		// The _only_ reason we call readTrack() is to get the track
-		// length of the existing track. Ideally we should just
-		// overwrite the track with another length. But the DMK file
-		// format cannot handle tracks with different lengths.
-		drive.readTrack(trackData);
+		unsigned trackLength = drive.getTrackLength();
+		setDrqRate(trackLength);
+		dataCurrent = 0;
+		dataAvailable = trackLength;
+		lastWasA1 = false;
+		lastWasCRC = false;
+		dataOutReg = dataReg;
+		dataRegWritten = false;
+		drqTime.reset(time); // DRQ = true
+
+		// Moment in time when first track byte gets written
+		schedule(FSM_WRITE_TRACK, drqTime + 1);
 	} catch (MSXException& /*e*/) {
-		endCmd();
+		endCmd(time);
 	}
-	trackData.clear(trackData.getLength());
-	setDrqRate();
-	dataCurrent = 0;
-	dataAvailable = trackData.getLength();
-	drqTime.reset(time); // DRQ = true
-	lastWasA1 = false;
-
-	// Moment in time when the track will be written (whether the CPU wrote
-	// all required data or not).
-	schedule(FSM_WRITE_TRACK, drqTime + dataAvailable);
 }
 
-void WD2793::doneWriteTrack()
+void WD2793::writeTrackData(EmuTime::param time)
 {
 	try {
-		// any lost data?
-		while (dataAvailable) {
-			statusReg |= LOST_DATA;
-			trackData.write(dataCurrent, 0);
-			dataCurrent++;
-			dataAvailable--;
-		}
-		drive.writeTrack(trackData);
-	} catch (MSXException&) {
-		// Ignore. Should rarely happen, because
-		// write-protected is already checked at the
-		// beginning of write-track command (maybe
-		// when disk is swapped during format)
-	}
-	endCmd();
-}
+		bool prevA1 = lastWasA1;
+		lastWasA1 = false;
 
+		// handle chars with special meaning
+		bool idam = false;
+		if (lastWasCRC) {
+			// 2nd CRC byte, don't transform
+			lastWasCRC = false;
+		} else if (dataOutReg == 0xF5) {
+			// write A1 with missing clock transitions
+			dataOutReg = 0xA1;
+			lastWasA1 = true;
+			// Initialize CRC: the calculated CRC value
+			// includes the 3 A1 bytes. So when starting
+			// from the initial value 0xffff, we should not
+			// re-initialize the CRC value on the 2nd and
+			// 3rd A1 byte. Though what we do instead is on
+			// each A1 byte initialize the value as if
+			// there were already 2 A1 bytes written.
+			crc.init<0xA1, 0xA1>();
+		} else if (dataOutReg == 0xF6) {
+			// write C2 with missing clock transitions
+			dataOutReg = 0xC2;
+		} else if (dataOutReg == 0xF7) {
+			// write 2 CRC bytes, big endian
+			dataOutReg = crc.getValue() >> 8; // high byte
+			lastWasCRC = true;
+		} else if (dataOutReg == 0xFE) {
+			// Record locations of 0xA1 (with missing clock
+			// transition) followed by 0xFE. The FE byte has
+			// no special meaning for the WD2793 itself,
+			// but it does for the DMK file format.
+			if (prevA1) idam = true;
+		}
+		// actually write (transformed) byte
+		drive.writeTrackByte(dataCurrent++, dataOutReg, idam);
+		if (!lastWasCRC) {
+			crc.update(dataOutReg);
+		}
+		--dataAvailable;
+
+		if (dataAvailable > 0) {
+			drqTime.reset(time); // DRQ = true
+
+			// Moment in time when next track byte gets written
+			schedule(FSM_WRITE_TRACK, drqTime + 1);
+
+			// prepare next byte
+			if (!lastWasCRC) {
+				if (dataRegWritten) {
+					dataOutReg = dataReg;
+					dataRegWritten = false;
+				} else {
+					dataOutReg = 0;
+					statusReg |= LOST_DATA;
+				}
+			} else {
+				dataOutReg = crc.getValue() & 0xFF; // low byte
+				// don't re-activate DRQ for 2nd byte of CRC
+				drqTime.reset(EmuTime::infinity); // DRQ = false
+			}
+		} else {
+			// Write track done
+			drive.flushTrack();
+			endCmd(time);
+		}
+	} catch (MSXException&) {
+		statusReg |= NOT_READY; // TODO which status bit should be set?
+		endCmd(time);
+	}
+}
 
 void WD2793::startType4Cmd(EmuTime::param time)
 {
@@ -930,8 +1051,14 @@ void WD2793::startType4Cmd(EmuTime::param time)
 	statusReg &= ~BUSY; // reset status on Busy
 }
 
-void WD2793::endCmd()
+void WD2793::endCmd(EmuTime::param time)
 {
+	if ((hldTime <= time) && (time < (hldTime + IDLE))) {
+		// HLD was active, start timeout period
+		// Real WD2793 waits for 15 index pulses. We approximate that
+		// here by waiting for 3s.
+		hldTime = time;
+	}
 	drqTime.reset(EmuTime::infinity); // DRQ   = false
 	irqTime = EmuTime::zero;          // INTRQ = true;
 	statusReg &= ~BUSY;
@@ -939,20 +1066,23 @@ void WD2793::endCmd()
 
 
 static std::initializer_list<enum_string<WD2793::FSMState>> fsmStateInfo = {
-	{ "NONE",            WD2793::FSM_NONE },
-	{ "SEEK",            WD2793::FSM_SEEK },
-	{ "TYPE2_WAIT_LOAD", WD2793::FSM_TYPE2_WAIT_LOAD },
-	{ "TYPE2_LOADED",    WD2793::FSM_TYPE2_LOADED },
-	{ "TYPE2_NOT_FOUND", WD2793::FSM_TYPE2_NOT_FOUND },
-	{ "TYPE2_ROTATED",   WD2793::FSM_TYPE2_ROTATED },
-	{ "CHECK_WRITE",     WD2793::FSM_CHECK_WRITE },
-	{ "WRITE_SECTOR",    WD2793::FSM_WRITE_SECTOR },
-	{ "TYPE3_WAIT_LOAD", WD2793::FSM_TYPE3_WAIT_LOAD },
-	{ "TYPE3_LOADED",    WD2793::FSM_TYPE3_LOADED },
-	{ "TYPE3_ROTATED",   WD2793::FSM_TYPE3_ROTATED },
-	{ "WRITE_TRACK",     WD2793::FSM_WRITE_TRACK },
-	{ "READ_TRACK",      WD2793::FSM_READ_TRACK },
-	{ "IDX_IRQ",         WD2793::FSM_IDX_IRQ }
+	{ "NONE",              WD2793::FSM_NONE },
+	{ "SEEK",              WD2793::FSM_SEEK },
+	{ "TYPE2_LOADED",      WD2793::FSM_TYPE2_LOADED },
+	{ "TYPE2_NOT_FOUND",   WD2793::FSM_TYPE2_NOT_FOUND },
+	{ "TYPE2_ROTATED",     WD2793::FSM_TYPE2_ROTATED },
+	{ "CHECK_WRITE",       WD2793::FSM_CHECK_WRITE },
+	{ "PRE_WRITE_SECTOR",  WD2793::FSM_PRE_WRITE_SECTOR },
+	{ "WRITE_SECTOR",      WD2793::FSM_WRITE_SECTOR },
+	{ "POST_WRITE_SECTOR", WD2793::FSM_POST_WRITE_SECTOR },
+	{ "TYPE3_LOADED",      WD2793::FSM_TYPE3_LOADED },
+	{ "TYPE3_ROTATED",     WD2793::FSM_TYPE3_ROTATED },
+	{ "WRITE_TRACK",       WD2793::FSM_WRITE_TRACK },
+	{ "READ_TRACK",        WD2793::FSM_READ_TRACK },
+	{ "IDX_IRQ",           WD2793::FSM_IDX_IRQ },
+	// for bw-compat savestate
+	{ "TYPE2_WAIT_LOAD",   WD2793::FSM_TYPE2_LOADED }, // was FSM_TYPE2_WAIT_LOAD
+	{ "TYPE3_WAIT_LOAD",   WD2793::FSM_TYPE3_LOADED }, // was FSM_TYPE3_WAIT_LOAD
 };
 SERIALIZE_ENUM(WD2793::FSMState, fsmStateInfo);
 
@@ -974,6 +1104,10 @@ SERIALIZE_ENUM(WD2793::FSMState, fsmStateInfo);
 // version 6: no layout changes, only added new enum value 'FSM_CHECK_WRITE'
 // version 7: replaced 'bool INTRQ' with 'EmuTime irqTime'
 // version 8: removed 'userData' from Schedulable
+// version 9: added 'trackDataValid'
+// version 10: removed 'trackData' and 'trackDataValid' (moved to RealDrive)
+// version 11: added 'dataOutReg', 'dataRegWritten', 'lastWasCRC'
+// version 12: added 'hldTime'
 template<typename Archive>
 void WD2793::serialize(Archive& ar, unsigned version)
 {
@@ -1025,45 +1159,13 @@ void WD2793::serialize(Archive& ar, unsigned version)
 		//ar.serialize("transferring", transferring);
 		//ar.serialize("formatting", formatting);
 		drqTime.reset(EmuTime::infinity);
-
-		// Compared to version 1, the datatransfer commands are
-		// implemented very differently. We don't attempt to restore
-		// the correct state from the old savestate. But we do give a
-		// warning.
-		if ((statusReg & BUSY) &&
-		    (((commandReg & 0xC0) == 0x80) ||  // read/write sector
-		     ((commandReg & 0xF0) == 0xF0))) { // write track
-			cliComm.printWarning(
-				"Loading an old savestate that had an "
-				"in-progress WD2793 data-transfer command. "
-				"This is not fully backwards-compatible and "
-				"could cause wrong emulation behavior.");
-		}
 	}
 
 	if (ar.versionAtLeast(version, 3)) {
-		ar.serialize("trackData", trackData);
 		ar.serialize("lastWasA1", lastWasA1);
 		word crcVal = crc.getValue();
 		ar.serialize("crc", crcVal);
 		crc.init(crcVal);
-	} else {
-		assert(ar.isLoader());
-		//ar.serialize_blob("dataBuffer", dataBuffer, sizeof(dataBuffer));
-		// Compared to version 1 or 2, the databuffer works different:
-		// before we only stored the data of the logical sector, now
-		// we store the full content of the raw track. We don't attempt
-		// to migrate the old format to the new one (it's not very
-		// easy). We only give a warning.
-		if ((statusReg & BUSY) &&
-		    (((commandReg & 0xC0) == 0x80) ||  // read/write sector
-		     ((commandReg & 0xF0) == 0xF0))) { // write track
-			cliComm.printWarning(
-				"Loading an old savestate that had an "
-				"in-progress WD2793 data-transfer command. "
-				"This is not fully backwards-compatible and "
-				"could cause wrong emulation behavior.");
-		}
 	}
 
 	if (ar.versionAtLeast(version, 5)) {
@@ -1085,6 +1187,40 @@ void WD2793::serialize(Archive& ar, unsigned version)
 			irqTime = bw_irqTime;
 		}
 	}
+
+	if (ar.versionAtLeast(version, 11)) {
+		ar.serialize("dataOutReg", dataOutReg);
+		ar.serialize("dataRegWritten", dataRegWritten);
+		ar.serialize("lastWasCRC", lastWasCRC);
+	} else {
+		assert(ar.isLoader());
+		dataOutReg = dataReg;
+		dataRegWritten = false;
+		lastWasCRC = false;
+	}
+
+	if (ar.versionBelow(version, 11)) {
+		assert(ar.isLoader());
+		// version 9->10: 'trackData' moved from FDC to RealDrive
+		// version 10->11: write commands are different
+		if (statusReg & BUSY) {
+			cliComm.printWarning(
+				"Loading an old savestate that has an "
+				"in-progress WD2793 command. This is not "
+				"fully backwards-compatible and can cause "
+				"wrong emulation behavior.");
+		}
+	}
+
+	if (ar.versionAtLeast(version, 12)) {
+		ar.serialize("hldTime", hldTime);
+	} else {
+		if (statusReg & BUSY) {
+			hldTime = getCurrentTime();
+		} else {
+			hldTime = EmuTime::infinity;
+		}
+	}
 }
 INSTANTIATE_SERIALIZE_METHODS(WD2793);
 
