@@ -20,7 +20,6 @@
 namespace openmsx {
 
 using std::string;
-using std::vector;
 
 HD::HD(const DeviceConfig& config)
 	: motherBoard(config.getMotherBoard())
@@ -54,6 +53,12 @@ HD::HD(const DeviceConfig& config)
 
 	file = File(filename, mode);
 	filesize = file.getSize();
+	if (mode == File::CREATE && filesize == 0) {
+		// OK, the file was just newly created. Now make sure the file
+		// is of the right (default) size
+		file.truncate(size_t(config.getChildDataAsInt("size")) * 1024 * 1024);
+		filesize = file.getSize();
+	}
 	tigerTree = make_unique<TigerTree>(
 		*this, filesize, filename.getResolved());
 
@@ -130,7 +135,7 @@ void HD::showProgress(size_t position, size_t maxPosition)
 	if (((now - lastProgressTime) > 1000000) ||
 	    ((position == maxPosition) && everDidProgress)) {
 		lastProgressTime = now;
-		int percentage = (100 * position) / maxPosition;
+		int percentage = int((100 * position) / maxPosition);
 		motherBoard.getMSXCliComm().printProgress(
 			"Calculating hash for " + filename.getResolved() +
 			"... " + StringOp::toString(percentage) + '%');
