@@ -43,9 +43,9 @@ private:
 };
 
 
-Rom::Rom(const string& name_, const string& description_,
+Rom::Rom(string name_, string description_,
          const DeviceConfig& config, const string& id /*= ""*/)
-	: name(name_), description(description_)
+	: name(std::move(name_)), description(std::move(description_))
 {
 	// Try all <rom> tags with matching "id" attribute.
 	string errors;
@@ -236,9 +236,9 @@ void Rom::init(MSXMotherBoard& motherBoard, const XMLElement& config,
 				make_unique<EmptyPatch>(rom, size);
 
 			for (auto& p : patchesElem->getChildren("ips")) {
-				Filename filename(p->getData(), context);
 				patch = make_unique<IPSPatch>(
-					filename, std::move(patch));
+					Filename(p->getData(), context),
+					std::move(patch));
 			}
 			auto patchSize = unsigned(patch->getSize());
 			if (patchSize <= size) {
@@ -348,9 +348,7 @@ Rom::Rom(Rom&& r) noexcept
 	if (romDebuggable) romDebuggable->moved(*this);
 }
 
-Rom::~Rom()
-{
-}
+Rom::~Rom() = default;
 
 string Rom::getFilename() const
 {
@@ -365,6 +363,20 @@ const Sha1Sum& Rom::getOriginalSHA1() const
 	return originalSha1;
 }
 
+void Rom::addPadding(unsigned newSize, byte filler)
+{
+	assert(newSize >= size);
+	if (newSize == size) return;
+
+	MemBuffer<byte> tmp(newSize);
+	auto* newData = tmp.data();
+	memcpy(newData, rom, size);
+	memset(newData + size, filler, newSize - size);
+
+	extendedRom = std::move(tmp);
+	rom = newData;
+	size = newSize;
+}
 
 RomDebuggable::RomDebuggable(Debugger& debugger_, Rom& rom_)
 	: debugger(debugger_), rom(&rom_)
