@@ -41,9 +41,10 @@
 #include "RomMatraInk.hh"
 #include "RomArc.hh"
 #include "MegaFlashRomSCCPlus.hh"
-#include "MegaFlashRomSCCPlusSD.hh"
+#include "KonamiUltimateCollection.hh"
 #include "RomDooly.hh"
 #include "RomMSXtra.hh"
+#include "RomRamFile.hh"
 #include "RomMultiRom.hh"
 #include "Rom.hh"
 #include "Reactor.hh"
@@ -176,6 +177,15 @@ unique_ptr<MSXDevice> create(const DeviceConfig& config)
 		type = RomInfo::nameToRomType(typestr);
 	}
 
+	// Store actual detected mapper type in config (override the possible
+	// 'auto' value). This way we're sure that on savestate/loadstate we're
+	// using the same mapper type (for example when the user's rom-database
+	// was updated).
+	// We do it at this point so that constructors used below can use this
+	// information for warning messages etc.
+	auto& writableConfig = const_cast<XMLElement&>(*config.getXML());
+	writableConfig.setChildData("mappertype", RomInfo::romTypeToName(type));
+
 	unique_ptr<MSXRom> result;
 	switch (type) {
 	case ROM_MIRRORED:
@@ -272,6 +282,10 @@ unique_ptr<MSXDevice> create(const DeviceConfig& config)
 		result = make_unique<RomAscii8_8>(
 			config, move(rom), RomAscii8_8::ASCII8_8);
 		break;
+	case ROM_ASCII8_32:
+		result = make_unique<RomAscii8_8>(
+			config, move(rom), RomAscii8_8::ASCII8_32);
+		break;
 	case ROM_ASCII8_2:
 		result = make_unique<RomAscii8_8>(
 			config, move(rom), RomAscii8_8::ASCII8_2);
@@ -354,8 +368,8 @@ unique_ptr<MSXDevice> create(const DeviceConfig& config)
 	case ROM_MEGAFLASHROMSCCPLUS:
 		result = make_unique<MegaFlashRomSCCPlus>(config, move(rom));
 		break;
-	case ROM_MEGAFLASHROMSCCPLUSSD:
-		result = make_unique<MegaFlashRomSCCPlusSD>(config, move(rom));
+	case ROM_KONAMI_ULTIMATE_COLLECTION:
+		result = make_unique<KonamiUltimateCollection>(config, move(rom));
 		break;
 	case ROM_DOOLY:
 		result = make_unique<RomDooly>(config, move(rom));
@@ -366,17 +380,13 @@ unique_ptr<MSXDevice> create(const DeviceConfig& config)
 	case ROM_MULTIROM:
 		result = make_unique<RomMultiRom>(config, move(rom));
 		break;
+	case ROM_RAMFILE:
+		result = make_unique<RomRamFile>(config, move(rom));
+		break;
 	default:
 		throw MSXException("Unknown ROM type");
 	}
 
-	// Store actual detected mapper type in config (override the possible
-	// 'auto' value). This way we're sure that on savestate/loadstate we're
-	// using the same mapper type (for example when the user's rom-database
-	// was updated).
-	auto& writableConfig = const_cast<XMLElement&>(*config.getXML());
-	writableConfig.setChildData("mappertype", RomInfo::romTypeToName(type));
-
 	return move(result);
 }
 
