@@ -6,7 +6,6 @@
 #include "FileOperations.hh"
 #include "StringOp.hh"
 #include "serialize.hh"
-#include <atomic>
 #include <cstdio>
 #include <cerrno>
 #include <cstring>
@@ -15,27 +14,20 @@ using std::string;
 
 namespace openmsx {
 
-// This only works for one simultaneous instance
-// TODO get rid of helper thread
-static std::atomic<bool> exitLoop(false);
-
 MidiInReader::MidiInReader(EventDistributor& eventDistributor_,
                            Scheduler& scheduler_,
                            CommandController& commandController)
 	: eventDistributor(eventDistributor_), scheduler(scheduler_)
-	, thread(this)
 	, readFilenameSetting(
 		commandController, "midi-in-readfilename",
 		"filename of the file where the MIDI input is read from",
 		"/dev/midi")
 {
 	eventDistributor.registerEventListener(OPENMSX_MIDI_IN_READER_EVENT, *this);
-	exitLoop = false;
 }
 
 MidiInReader::~MidiInReader()
 {
-	exitLoop = true;
 	eventDistributor.unregisterEventListener(OPENMSX_MIDI_IN_READER_EVENT, *this);
 }
 
@@ -55,13 +47,13 @@ void MidiInReader::plugHelper(Connector& connector_, EmuTime::param /*time*/)
 
 	setConnector(&connector_); // base class will do this in a moment,
 	                           // but thread already needs it
-	thread.start();
+	thread = std::thread([this]() { run(); });
 }
 
 void MidiInReader::unplugHelper(EmuTime::param /*time*/)
 {
-	std::lock_guard<std::mutex> lock(mutex);
-	thread.stop();
+	poller.abort();
+	thread.join();
 	file.reset();
 }
 
@@ -79,14 +71,20 @@ string_ref MidiInReader::getDescription() const
 }
 
 
-// Runnable
 void MidiInReader::run()
 {
 	byte buf;
 	if (!file) return;
 	while (true) {
+#ifndef _WIN32
+		if (poller.poll(fileno(file.get()))) {
+			break;
+		}
+#endif
 		size_t num = fread(&buf, 1, 1, file.get());
-		if (exitLoop) break;
+		if (poller.aborted()) {
+			break;
+		}
 		if (num != 1) {
 			continue;
 		}
