@@ -10,8 +10,8 @@ using std::string;
 namespace openmsx {
 
 MidiOutConnector::MidiOutConnector(PluggingController& pluggingController_,
-                                   string_ref name_)
-	: Connector(pluggingController_, name_,
+                                   std::string name_)
+	: Connector(pluggingController_, std::move(name_),
 	            make_unique<DummyMidiOutDevice>())
 {
 }
