@@ -2,7 +2,6 @@
 #include "MSXMixer.hh"
 #include "NullSoundDriver.hh"
 #include "SDLSoundDriver.hh"
-#include "DirectXSoundDriver.hh"
 #include "CommandController.hh"
 #include "CliComm.hh"
 #include "MSXException.hh"
@@ -23,23 +22,11 @@ static const int defaultsamples = 2560;
 static const int defaultsamples = 1024;
 #endif
 
-static Mixer::SoundDriverType getDefaultSoundDriver()
-{
-#ifdef _WIN32
-	return Mixer::SND_DIRECTX;
-#else
-	return Mixer::SND_SDL;
-#endif
-}
-
 static EnumSetting<Mixer::SoundDriverType>::Map getSoundDriverMap()
 {
 	EnumSetting<Mixer::SoundDriverType>::Map soundDriverMap = {
 		{ "null", Mixer::SND_NULL },
 		{ "sdl",  Mixer::SND_SDL } };
-#ifdef _WIN32
-	soundDriverMap.emplace_back("directx", Mixer::SND_DIRECTX);
-#endif
 	return soundDriverMap;
 }
 
@@ -49,7 +36,7 @@ Mixer::Mixer(Reactor& reactor_, CommandController& commandController_)
 	, soundDriverSetting(
 		commandController, "sound_driver",
 		"select the sound output driver",
-		getDefaultSoundDriver(), getSoundDriverMap())
+		Mixer::SND_SDL, getSoundDriverMap())
 	, muteSetting(
 		commandController, "mute",
 		"(un)mute the emulation sound", false, Setting::DONT_SAVE)
@@ -105,13 +92,6 @@ void Mixer::reloadDriver()
 				frequencySetting.getInt(),
 				samplesSetting.getInt());
 			break;
-#ifdef _WIN32
-		case SND_DIRECTX:
-			driver = make_unique<DirectXSoundDriver>(
-				frequencySetting.getInt(),
-				samplesSetting.getInt());
-			break;
-#endif
 		default:
 			UNREACHABLE;
 		}
