@@ -85,7 +85,7 @@ static byte eg_inc[19 * RATE_STEPS] = {
 };
 
 
-#define O(a) (a*RATE_STEPS)
+#define O(a) ((a) * RATE_STEPS)
 // note that there is no O(17) in this table - it's directly in the code
 static byte eg_rate_select[32 + 64 + 32] = {
 // Envelope Generator rates (32 + 64 rates + 32 RKS)
@@ -132,7 +132,7 @@ O(16),O(16),O(16),O(16),O(16),O(16),O(16),O(16)
 // rate  0,    1,    2,   3,   4,   5,  6,  7,  8,  9, 10, 11, 12, 13, 14, 15
 // shift 11,   10,   9,   8,   7,   6,  5,  4,  3,  2, 1,  0,  0,  0,  0,  0
 // mask  2047, 1023, 511, 255, 127, 63, 31, 15, 7,  3, 1,  0,  0,  0,  0,  0
-#define O(a) (a*1)
+#define O(a) ((a) * 1)
 static byte eg_rate_shift[32 + 64 + 32] = {
 // Envelope Generator counter shifts (32 + 64 rates + 32 RKS)
 // 32 infinite time rates
@@ -892,8 +892,8 @@ void YM2151::reset(EmuTime::param time)
 	test = 0;
 
 	irq_enable = 0;
-	timer1->setStart(0, time);
-	timer2->setStart(0, time);
+	timer1->setStart(false, time);
+	timer2->setStart(false, time);
 
 	noise     = 0;
 	noise_rng = 0;
