@@ -55,7 +55,7 @@ static const int mix_level[8] = {
 
 // decay level table (3dB per step)
 // 0 - 15: 0, 3, 6, 9,12,15,18,21,24,27,30,33,36,39,42,93 (dB)
-#define SC(db) unsigned(db * (2.0f / ENV_STEP))
+#define SC(db) unsigned((db) * (2.0f / ENV_STEP))
 static const unsigned dl_tab[16] = {
  SC( 0), SC( 1), SC( 2), SC(3 ), SC(4 ), SC(5 ), SC(6 ), SC( 7),
  SC( 8), SC( 9), SC(10), SC(11), SC(12), SC(13), SC(14), SC(31)
@@ -85,7 +85,7 @@ static const byte eg_inc[15 * RATE_STEPS] = {
 	0, 0,  0, 0,  0, 0,  0, 0, // 14  infinity rates for attack and decay(s)
 };
 
-#define O(a) (a * RATE_STEPS)
+#define O(a) ((a) * RATE_STEPS)
 static const byte eg_rate_select[64] = {
 	O( 0),O( 1),O( 2),O( 3),
 	O( 0),O( 1),O( 2),O( 3),
@@ -133,7 +133,7 @@ static const byte eg_rate_shift[64] = {
 
 // number of steps to take in quarter of lfo frequency
 // TODO check if frequency matches real chip
-#define O(a) int((EG_TIMER_OVERFLOW / a) / 6)
+#define O(a) int((EG_TIMER_OVERFLOW / (a)) / 6)
 static const int lfo_period[8] = {
 	O(0.168f), O(2.019f), O(3.196f), O(4.206f),
 	O(5.215f), O(5.888f), O(6.224f), O(7.066f)
@@ -141,7 +141,7 @@ static const int lfo_period[8] = {
 #undef O
 
 
-#define O(a) int(a * 65536)
+#define O(a) int((a) * 65536)
 static const int vib_depth[8] = {
 	O( 0.0f  ), O( 3.378f), O( 5.065f), O( 6.750f),
 	O(10.114f), O(20.170f), O(40.106f), O(79.307f)
@@ -149,7 +149,7 @@ static const int vib_depth[8] = {
 #undef O
 
 
-#define SC(db) int(db * (2.0f / ENV_STEP))
+#define SC(db) int((db) * (2.0f / ENV_STEP))
 static const int am_depth[8] = {
 	SC(0.0f  ), SC(1.781f), SC(2.906f), SC( 3.656f),
 	SC(4.406f), SC(5.906f), SC(7.406f), SC(11.91f )
@@ -746,8 +746,8 @@ YMF278::YMF278(const std::string& name_, int ramSize_,
 	, debugRegisters(motherBoard, getName())
 	, debugMemory   (motherBoard, getName())
 	, rom(getName() + " ROM", "rom", config)
-	, ramSize(ramSize_ * 1024) // in kB
-	, ram(ramSize)
+	, ram(config, getName() + " RAM", "YMF278 sample RAM",
+	      ramSize_ * 1024) // size in kB
 {
 	if (rom.getSize() != 0x200000) { // 2MB
 		throw MSXException(
@@ -790,7 +790,7 @@ YMF278::~YMF278()
 
 void YMF278::clearRam()
 {
-	memset(ram.data(), 0, ramSize);
+	ram.clear(0);
 }
 
 void YMF278::reset(EmuTime::param time)
@@ -869,7 +869,7 @@ unsigned YMF278::getRamAddress(unsigned addr) const
 				// 1st 128kB of SRAM1
 				break;
 			case 0x020000: // [0x3A0000-0x3BFFFF]
-				if (ramSize == 256 * 1024) {
+				if (ram.getSize() == 256 * 1024) {
 					// 2nd 128kB SRAM chip
 				} else {
 					// 2nd block of 128kB in SRAM2
@@ -890,7 +890,7 @@ unsigned YMF278::getRamAddress(unsigned addr) const
 			addr = unsigned(-1); // unmapped
 		}
 	}
-	if (ramSize == 640 * 1024) {
+	if (ram.getSize() == 640 * 1024) {
 		// Verified on real MoonSound cartridge (v2.0): In case of
 		// 640kB (1x512kB + 1x128kB), the 128kB SRAM chip is 4 times
 		// visible. None of the other SRAM configurations show similar
@@ -911,7 +911,7 @@ byte YMF278::readMem(unsigned address) const
 		return rom[address];
 	} else {
 		unsigned ramAddr = getRamAddress(address);
-		if (ramAddr < ramSize) {
+		if (ramAddr < ram.getSize()) {
 			return ram[ramAddr];
 		} else {
 			// unmapped region
@@ -927,8 +927,8 @@ void YMF278::writeMem(unsigned address, byte value)
 		// can't write to ROM
 	} else {
 		unsigned ramAddr = getRamAddress(address);
-		if (ramAddr < ramSize) {
-			ram[ramAddr] = value;
+		if (ramAddr < ram.getSize()) {
+			ram.write(ramAddr, value);
 		} else {
 			// can't write to unmapped memory
 		}
@@ -1012,12 +1012,17 @@ void YMF278::Slot::serialize(Archive& ar, unsigned version)
 // version 1: initial version
 // version 2: loadTime and busyTime moved to MSXMoonSound class
 // version 3: memadr cannot be restored from register values
+// version 4: implement ram via Ram class
 template<typename Archive>
 void YMF278::serialize(Archive& ar, unsigned version)
 {
 	ar.serialize("slots", slots);
 	ar.serialize("eg_cnt", eg_cnt);
-	ar.serialize_blob("ram", ram.data(), ramSize);
+	if (ar.versionAtLeast(version, 4)) {
+		ar.serialize("ram", ram);
+	} else {
+		ar.serialize_blob("ram", ram.getWriteBackdoor(), ram.getSize());
+	}
 	ar.serialize_blob("registers", regs, sizeof(regs));
 	if (ar.versionAtLeast(version, 3)) { // must come after 'regs'
 		ar.serialize("memadr", memadr);
