@@ -1430,23 +1430,23 @@ static const std::array<std::array<uint8_t,3>,16> THREE_BIT_RGB_PALETTE = {{
 // Source: TMS9918/28/29 Data Book, page 2-17.
 
 const float TMS9XXXA_ANALOG_OUTPUT[16][3] = {
-//           Y   R-Y   B-Y  voltages
-	{ 0.00, 0.47, 0.47 },
-	{ 0.00, 0.47, 0.47 },
-	{ 0.53, 0.07, 0.20 },
-	{ 0.67, 0.17, 0.27 },
-	{ 0.40, 0.40, 1.00 },
-	{ 0.53, 0.43, 0.93 },
-	{ 0.47, 0.83, 0.30 },
-	{ 0.73, 0.00, 0.70 },
-	{ 0.53, 0.93, 0.27 },
-	{ 0.67, 0.93, 0.27 },
-	{ 0.73, 0.57, 0.07 },
-	{ 0.80, 0.57, 0.17 },
-	{ 0.47, 0.13, 0.23 },
-	{ 0.53, 0.73, 0.67 },
-	{ 0.80, 0.47, 0.47 },
-	{ 1.00, 0.47, 0.47 },
+	//  Y     R-Y    B-Y    voltages
+	{ 0.00f, 0.47f, 0.47f },
+	{ 0.00f, 0.47f, 0.47f },
+	{ 0.53f, 0.07f, 0.20f },
+	{ 0.67f, 0.17f, 0.27f },
+	{ 0.40f, 0.40f, 1.00f },
+	{ 0.53f, 0.43f, 0.93f },
+	{ 0.47f, 0.83f, 0.30f },
+	{ 0.73f, 0.00f, 0.70f },
+	{ 0.53f, 0.93f, 0.27f },
+	{ 0.67f, 0.93f, 0.27f },
+	{ 0.73f, 0.57f, 0.07f },
+	{ 0.80f, 0.57f, 0.17f },
+	{ 0.47f, 0.13f, 0.23f },
+	{ 0.53f, 0.73f, 0.67f },
+	{ 0.80f, 0.47f, 0.47f },
+	{ 1.00f, 0.47f, 0.47f },
 };
 
 const std::array<std::array<uint8_t,3>,16> VDP::getMSX1Palette() const
