@@ -13,9 +13,11 @@ V9990VRAM::V9990VRAM(V9990& vdp_, EmuTime::param /*time*/)
 
 void V9990VRAM::clear()
 {
-	//	Initialize memory. Alternate 0x00/0xff every 512 bytes.
-	for(unsigned i=0; i<data.getSize(); ++i)
-		data[i] = (i & 0x200) ? 0xff : 0;
+	// Initialize memory. Alternate 0x00/0xff every 512 bytes.
+	auto* d = data.getWriteBackdoor();
+	for (unsigned i = 0; i < data.getSize(); ++i) {
+		d[i] = (i & 0x200) ? 0xff : 0;
+	}
 }
 
 unsigned V9990VRAM::mapAddress(unsigned address)
@@ -41,10 +43,9 @@ byte V9990VRAM::readVRAMCPU(unsigned address, EmuTime::param time)
 void V9990VRAM::writeVRAMCPU(unsigned address, byte value, EmuTime::param time)
 {
 	sync(time);
-	data[mapAddress(address)] = value;
+	data.write(mapAddress(address), value);
 }
 
-
 template<typename Archive>
 void V9990VRAM::serialize(Archive& ar, unsigned /*version*/)
 {
